==> org.eclipse.incquery.uml.source_1.0.1.201508191609.jar: org/eclipse/incquery/uml/derivedfeatures/StructuredClassifierPartMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.StructuredClassifierPartQuerySpecification;
import org.eclipse.uml2.uml.Property;
import org.eclipse.uml2.uml.StructuredClassifier;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.structuredClassifierPart pattern,
 * to be used in conjunction with {@link StructuredClassifierPartMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see StructuredClassifierPartMatcher
 * @see StructuredClassifierPartProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class StructuredClassifierPartMatch extends BasePatternMatch {
  private StructuredClassifier fStructuredClassifier;
  
  private Property fPart;
  
  private static List<String> parameterNames = makeImmutableList("structuredClassifier", "part");
  
  private StructuredClassifierPartMatch(final StructuredClassifier pStructuredClassifier, final Property pPart) {
    this.fStructuredClassifier = pStructuredClassifier;
    this.fPart = pPart;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("structuredClassifier".equals(parameterName)) return this.fStructuredClassifier;
    if ("part".equals(parameterName)) return this.fPart;
    return null;
  }
  
  public StructuredClassifier getStructuredClassifier() {
    return this.fStructuredClassifier;
  }
  
  public Property getPart() {
    return this.fPart;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("structuredClassifier".equals(parameterName) ) {
    	this.fStructuredClassifier = (org.eclipse.uml2.uml.StructuredClassifier) newValue;
    	return true;
    }
    if ("part".equals(parameterName) ) {
    	this.fPart = (org.eclipse.uml2.uml.Property) newValue;
    	return true;
    }
    return false;
  }
  
  public void setStructuredClassifier(final StructuredClassifier pStructuredClassifier) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fStructuredClassifier = pStructuredClassifier;
  }
  
  public void setPart(final Property pPart) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fPart = pPart;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.structuredClassifierPart";
  }
  
  @Override
  public List<String> parameterNames() {
    return StructuredClassifierPartMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fStructuredClassifier, fPart};
  }
  
  @Override
  public StructuredClassifierPartMatch toImmutable() {
    return isMutable() ? newMatch(fStructuredClassifier, fPart) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"structuredClassifier\"=" + prettyPrintValue(fStructuredClassifier) + ", ");
    
    result.append("\"part\"=" + prettyPrintValue(fPart)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fStructuredClassifier == null) ? 0 : fStructuredClassifier.hashCode());
    result = prime * result + ((fPart == null) ? 0 : fPart.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof StructuredClassifierPartMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    StructuredClassifierPartMatch other = (StructuredClassifierPartMatch) obj;
    if (fStructuredClassifier == null) {if (other.fStructuredClassifier != null) return false;}
    else if (!fStructuredClassifier.equals(other.fStructuredClassifier)) return false;
    if (fPart == null) {if (other.fPart != null) return false;}
    else if (!fPart.equals(other.fPart)) return false;
    return true;
  }
  
  @Override
  public StructuredClassifierPartQuerySpecification specification() {
    try {
    	return StructuredClassifierPartQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static StructuredClassifierPartMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pStructuredClassifier the fixed value of pattern parameter structuredClassifier, or null if not bound.
   * @param pPart the fixed value of pattern parameter part, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static StructuredClassifierPartMatch newMutableMatch(final StructuredClassifier pStructuredClassifier, final Property pPart) {
    return new Mutable(pStructuredClassifier, pPart);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pStructuredClassifier the fixed value of pattern parameter structuredClassifier, or null if not bound.
   * @param pPart the fixed value of pattern parameter part, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static StructuredClassifierPartMatch newMatch(final StructuredClassifier pStructuredClassifier, final Property pPart) {
    return new Immutable(pStructuredClassifier, pPart);
  }
  
  private static final class Mutable extends StructuredClassifierPartMatch {
    Mutable(final StructuredClassifier pStructuredClassifier, final Property pPart) {
      super(pStructuredClassifier, pPart);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends StructuredClassifierPartMatch {
    Immutable(final StructuredClassifier pStructuredClassifier, final Property pPart) {
      super(pStructuredClassifier, pPart);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.2.0.201602080945.jar: org/eclipse/incquery/uml/derivedfeatures/StructuredClassifierPartMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.StructuredClassifierPartQuerySpecification;
import org.eclipse.uml2.uml.Property;
import org.eclipse.uml2.uml.StructuredClassifier;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.structuredClassifierPart pattern,
 * to be used in conjunction with {@link StructuredClassifierPartMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see StructuredClassifierPartMatcher
 * @see StructuredClassifierPartProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class StructuredClassifierPartMatch extends BasePatternMatch {
  private StructuredClassifier fStructuredClassifier;
  
  private Property fPart;
  
  private static List<String> parameterNames = makeImmutableList("structuredClassifier", "part");
  
  private StructuredClassifierPartMatch(final StructuredClassifier pStructuredClassifier, final Property pPart) {
    this.fStructuredClassifier = pStructuredClassifier;
    this.fPart = pPart;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("structuredClassifier".equals(parameterName)) return this.fStructuredClassifier;
    if ("part".equals(parameterName)) return this.fPart;
    return null;
  }
  
  public StructuredClassifier getStructuredClassifier() {
    return this.fStructuredClassifier;
  }
  
  public Property getPart() {
    return this.fPart;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("structuredClassifier".equals(parameterName) ) {
    	this.fStructuredClassifier = (StructuredClassifier) newValue;
    	return true;
    }
    if ("part".equals(parameterName) ) {
    	this.fPart = (Property) newValue;
    	return true;
    }
    return false;
  }
  
  public void setStructuredClassifier(final StructuredClassifier pStructuredClassifier) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fStructuredClassifier = pStructuredClassifier;
  }
  
  public void setPart(final Property pPart) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fPart = pPart;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.structuredClassifierPart";
  }
  
  @Override
  public List<String> parameterNames() {
    return StructuredClassifierPartMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fStructuredClassifier, fPart};
  }
  
  @Override
  public StructuredClassifierPartMatch toImmutable() {
    return isMutable() ? newMatch(fStructuredClassifier, fPart) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"structuredClassifier\"=" + prettyPrintValue(fStructuredClassifier) + ", ");
    
    result.append("\"part\"=" + prettyPrintValue(fPart)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fStructuredClassifier == null) ? 0 : fStructuredClassifier.hashCode());
    result = prime * result + ((fPart == null) ? 0 : fPart.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof StructuredClassifierPartMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    StructuredClassifierPartMatch other = (StructuredClassifierPartMatch) obj;
    if (fStructuredClassifier == null) {if (other.fStructuredClassifier != null) return false;}
    else if (!fStructuredClassifier.equals(other.fStructuredClassifier)) return false;
    if (fPart == null) {if (other.fPart != null) return false;}
    else if (!fPart.equals(other.fPart)) return false;
    return true;
  }
  
  @Override
  public StructuredClassifierPartQuerySpecification specification() {
    try {
    	return StructuredClassifierPartQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static StructuredClassifierPartMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pStructuredClassifier the fixed value of pattern parameter structuredClassifier, or null if not bound.
   * @param pPart the fixed value of pattern parameter part, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static StructuredClassifierPartMatch newMutableMatch(final StructuredClassifier pStructuredClassifier, final Property pPart) {
    return new Mutable(pStructuredClassifier, pPart);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pStructuredClassifier the fixed value of pattern parameter structuredClassifier, or null if not bound.
   * @param pPart the fixed value of pattern parameter part, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static StructuredClassifierPartMatch newMatch(final StructuredClassifier pStructuredClassifier, final Property pPart) {
    return new Immutable(pStructuredClassifier, pPart);
  }
  
  private static final class Mutable extends StructuredClassifierPartMatch {
    Mutable(final StructuredClassifier pStructuredClassifier, final Property pPart) {
      super(pStructuredClassifier, pPart);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends StructuredClassifierPartMatch {
    Immutable(final StructuredClassifier pStructuredClassifier, final Property pPart) {
      super(pStructuredClassifier, pPart);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}
